Learn R Programming

GSAQ (version 1.0)

qtldist: QTL wise distribution of genes in the selected geneset

Description

Computation of number of qtl-hit genes in each QTL and also QTL wise distribution of genes in the selected geneset

Usage

qtldist(geneset, genelist, qtl, plot)

Arguments

geneset
geneset is a vector of characters representing the names of genes/ gene ids selected from the whole gene space by using a gene selection method.
genelist
genelist is a N by 3 dataframe/ matrix (genes/gene ids as row names); where, N represents the number of genes in the whole gene space: first coloumn represnting the chromosomal location of genes: second coloumn representing the start position of genes in terms of basepairs: third coloumn representing the end position of genes in terms of basepairs in their respective chromosomes.
qtl
qtl is a Q by 3 dataframe/matrix (qtl names/qtl ids as row names);where, Q represents the number of qtls: first coloumn represnting the chromosomal location of qtls: second coloumn representing the start position of qtls in terms of basepairs: third coloumn representing the end position of qtls in terms of basepairs in their respective chromosomes.
plot
plot is a character string used to plot the QTL wise distribution of genes in the selected gene set. It can be either TRUE/FALSE.

Value

Examples

Run this code
data(rice_salt)
data(genelist)
data(qtl_salt)
x=as.data.frame(rice_salt[-1,])
y=as.numeric(rice_salt[1,])
geneset= GeneSelect(x, y, s=50, method="t-score")$selectgenes
genelist=as.data.frame(genelist)
qtl=as.data.frame(qtl_salt)
qtldist(geneset, genelist, qtl, plot=TRUE)

Run the code above in your browser using DataLab